@@ -19,8 +19,13 @@
 
 #include <gtk/gtk.h>
 #include <champlain/champlain.h>
+#include <champlain/champlain-memphis-renderer.h>
 #include <champlain-gtk/champlain-gtk.h>
 #include <clutter-gtk/clutter-gtk.h>
+#include <string.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/socket.h>
 
 #define N_COLS 2
 #define COL_ID 0
@@ -40,9 +45,12 @@ static GtkWidget *polycolor, *polyminz, *polymaxz;
 static GtkWidget *linecolor, *linesize, *lineminz, *linemaxz;
 static GtkWidget *bordercolor, *bordersize, *borderminz, *bordermaxz;
 static GtkWidget *textcolor, *textsize, *textminz, *textmaxz;
-static MemphisRule *current_rule = NULL;
+static ChamplainMemphisRule *current_rule = NULL;
 
 static ChamplainMapSource *tile_source = NULL;
+static ChamplainMemoryCache *memory_cache = NULL;
+
+static ChamplainView *champlain_view;
 
 /*
  * Terminate the main loop.
@@ -53,8 +61,10 @@ on_destroy (GtkWidget *widget, gpointer data)
   gtk_main_quit ();
 }
 
-static void color_gdk_to_clutter (const GdkColor *gdk_color,
-                                  ClutterColor *clutter_color)
+
+static void
+color_gdk_to_clutter (const GdkColor *gdk_color,
+    ClutterColor *clutter_color)
 {
   clutter_color->red = CLAMP (((gdk_color->red / 65535.0) * 255), 0, 255);
   clutter_color->green = CLAMP (((gdk_color->green / 65535.0) * 255), 0, 255);
@@ -62,22 +72,34 @@ static void color_gdk_to_clutter (const GdkColor *gdk_color,
   clutter_color->alpha = 255;
 }
 
-static void color_clutter_to_gdk (const ClutterColor *clutter_color,
-                                  GdkColor *gdk_color)
+
+static void
+color_clutter_to_gdk (const ClutterColor *clutter_color,
+    GdkColor *gdk_color)
 {
   gdk_color->red = ((guint16) clutter_color->red) << 8;
   gdk_color->green = ((guint16) clutter_color->green) << 8;
   gdk_color->blue = ((guint16) clutter_color->blue) << 8;
 }
 
+
 static void
-data_source_state_changed (ChamplainView *view,
-                           GParamSpec *gobject,
-                           GtkImage *image)
+reload_tiles ()
+{
+  if (memory_cache)
+    champlain_memory_cache_clean (memory_cache);
+  champlain_view_reload_tiles (champlain_view);
+}
+
+
+static void
+data_source_state_changed (ChamplainNetworkBboxTileSource *source,
+    GParamSpec *gobject,
+    GtkImage *image)
 {
   ChamplainState state;
 
-  g_object_get (G_OBJECT (view), "state", &state, NULL);
+  g_object_get (G_OBJECT (source), "state", &state, NULL);
   if (state == CHAMPLAIN_STATE_LOADING)
     {
       gtk_image_set_from_stock (image, GTK_STOCK_NETWORK, GTK_ICON_SIZE_BUTTON);
@@ -88,54 +110,40 @@ data_source_state_changed (ChamplainView *view,
       gtk_image_clear (image);
       g_print ("NET DATA SOURCE STATE: done\n");
     }
+  
+  reload_tiles ();
 }
 
-static void
-load_local_map_data (ChamplainMapSource *source)
-{
-  ChamplainLocalMapDataSource *map_data_source;
-
-  map_data_source = CHAMPLAIN_LOCAL_MAP_DATA_SOURCE (
-                      champlain_memphis_tile_source_get_map_data_source (
-                        CHAMPLAIN_MEMPHIS_TILE_SOURCE (source)));
-
-  champlain_local_map_data_source_load_map_data (map_data_source,
-      maps[map_index]);
-}
 
 static void
-load_network_map_data (ChamplainMapSource *source, ChamplainView *view)
+load_network_map_data (ChamplainNetworkBboxTileSource *source, ChamplainView *view)
 {
-  ChamplainNetworkMapDataSource *map_data_source;
   gdouble lat, lon;
 
-  map_data_source = CHAMPLAIN_NETWORK_MAP_DATA_SOURCE (
-                      champlain_memphis_tile_source_get_map_data_source (
-                        CHAMPLAIN_MEMPHIS_TILE_SOURCE (source)));
-
-  g_signal_connect (map_data_source, "notify::state", G_CALLBACK (data_source_state_changed),
-                    map_data_state_img);
+  g_signal_connect (source, "notify::state", G_CALLBACK (data_source_state_changed),
+      map_data_state_img);
 
   g_object_get (G_OBJECT (view), "latitude", &lat, "longitude", &lon, NULL);
 
-  champlain_network_map_data_source_load_map_data (map_data_source,
+  champlain_network_bbox_tile_source_load_map_data (source,
       lon - 0.008, lat - 0.008, lon + 0.008, lat + 0.008);
 }
 
+
 static void
 load_rules_into_gui (ChamplainView *view)
 {
-  GList* ids, *ptr;
+  GList *ids, *ptr;
   GtkTreeModel *store;
   GtkTreeIter iter;
   GdkColor gdk_color;
   ClutterColor *clutter_color;
+  ChamplainMemphisRenderer *renderer;
 
-  ids = champlain_memphis_tile_source_get_rule_ids (
-          CHAMPLAIN_MEMPHIS_TILE_SOURCE(tile_source));
+  renderer = CHAMPLAIN_MEMPHIS_RENDERER (champlain_map_source_get_renderer (CHAMPLAIN_MAP_SOURCE (tile_source)));
+  ids = champlain_memphis_renderer_get_rule_ids (renderer);
 
-  clutter_color = champlain_memphis_tile_source_get_background_color (
-                    CHAMPLAIN_MEMPHIS_TILE_SOURCE(tile_source));
+  clutter_color = champlain_memphis_renderer_get_background_color (renderer);
 
   color_clutter_to_gdk (clutter_color, &gdk_color);
   clutter_color_free (clutter_color);
@@ -156,6 +164,7 @@ load_rules_into_gui (ChamplainView *view)
   g_list_free (ids);
 }
 
+
 static void
 rule_window_close_cb (GtkWidget *widget, gpointer data)
 {
@@ -165,10 +174,11 @@ rule_window_close_cb (GtkWidget *widget, gpointer data)
   rule_edit_window = NULL;
 }
 
+
 static void
-rule_apply_cb (GtkWidget *widget, ChamplainMemphisTileSource *source)
+rule_apply_cb (GtkWidget *widget, ChamplainMemphisRenderer *renderer)
 {
-  MemphisRule *rule = current_rule;
+  ChamplainMemphisRule *rule = current_rule;
   GdkColor color;
 
   if (rule->polygon)
@@ -211,11 +221,13 @@ rule_apply_cb (GtkWidget *widget, ChamplainMemphisTileSource *source)
       rule->text->z_max = gtk_spin_button_get_value (GTK_SPIN_BUTTON (textmaxz));
     }
 
-  champlain_memphis_tile_source_set_rule (source, rule);
+  champlain_memphis_renderer_set_rule (renderer, rule);
+  reload_tiles ();
 }
 
+
 GtkWidget *
-gtk_memphis_prop_new (gint type, MemphisRuleAttr *attr)
+gtk_memphis_prop_new (gint type, ChamplainMemphisRuleAttr *attr)
 {
   GtkWidget *hbox, *cb, *sb1, *sb2, *sb3;
   GdkColor gcolor;
@@ -272,9 +284,10 @@ gtk_memphis_prop_new (gint type, MemphisRuleAttr *attr)
   return hbox;
 }
 
+
 static void
-create_rule_edit_window (MemphisRule *rule, gchar* id,
-                         ChamplainMemphisTileSource *source)
+create_rule_edit_window (ChamplainMemphisRule *rule, gchar *id,
+    ChamplainMemphisRenderer *renderer)
 {
   GtkWidget *label, *table, *props, *button;
 
@@ -284,22 +297,22 @@ create_rule_edit_window (MemphisRule *rule, gchar* id,
   gtk_container_set_border_width (GTK_CONTAINER (rule_edit_window), 10);
   gtk_window_set_title (GTK_WINDOW (rule_edit_window), id);
   gtk_window_set_position (GTK_WINDOW (rule_edit_window),
-                           GTK_WIN_POS_CENTER_ON_PARENT);
+      GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_transient_for (GTK_WINDOW (rule_edit_window),
-                                GTK_WINDOW (window));
+      GTK_WINDOW (window));
   g_signal_connect (G_OBJECT (rule_edit_window), "destroy",
-                    G_CALLBACK (rule_window_close_cb), NULL);
+      G_CALLBACK (rule_window_close_cb), NULL);
 
   table = gtk_table_new (6, 2, FALSE);
   gtk_table_set_col_spacings (GTK_TABLE (table), 8);
   gtk_table_set_row_spacings (GTK_TABLE (table), 8);
   label = gtk_label_new (NULL);
 
-  if (rule->type == MEMPHIS_RULE_TYPE_WAY)
+  if (rule->type == CHAMPLAIN_MEMPHIS_RULE_TYPE_WAY)
     gtk_label_set_markup (GTK_LABEL (label), "<b>Way properties</b>");
-  else if (rule->type == MEMPHIS_RULE_TYPE_NODE)
+  else if (rule->type == CHAMPLAIN_MEMPHIS_RULE_TYPE_NODE)
     gtk_label_set_markup (GTK_LABEL (label), "<b>Node properties</b>");
-  else if (rule->type == MEMPHIS_RULE_TYPE_RELATION)
+  else if (rule->type == CHAMPLAIN_MEMPHIS_RULE_TYPE_RELATION)
     gtk_label_set_markup (GTK_LABEL (label), "<b>Relation properties</b>");
   else
     gtk_label_set_markup (GTK_LABEL (label), "<b>Unknown type</b>");
@@ -340,10 +353,10 @@ create_rule_edit_window (MemphisRule *rule, gchar* id,
   button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
   g_signal_connect (G_OBJECT (button), "clicked",
-                    G_CALLBACK (rule_window_close_cb), NULL);
+      G_CALLBACK (rule_window_close_cb), NULL);
   button = gtk_button_new_from_stock (GTK_STOCK_APPLY);
   g_signal_connect (G_OBJECT (button), "clicked",
-                    G_CALLBACK (rule_apply_cb), source);
+      G_CALLBACK (rule_apply_cb), renderer);
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
   GtkWidget *mainbox = gtk_vbox_new (FALSE, 0);
@@ -354,39 +367,38 @@ create_rule_edit_window (MemphisRule *rule, gchar* id,
   gtk_widget_show_all (rule_edit_window);
 }
 
+
 static void
 zoom_to_map_data (GtkWidget *widget, ChamplainView *view)
 {
-  ChamplainMapDataSource *data_source;
+  ChamplainMemphisRenderer *renderer;
   ChamplainBoundingBox *bbox;
   gdouble lat, lon;
 
-  data_source = champlain_memphis_tile_source_get_map_data_source (CHAMPLAIN_MEMPHIS_TILE_SOURCE(tile_source));
-  g_object_get (G_OBJECT (data_source), "bounding-box", &bbox, NULL);
+  renderer = CHAMPLAIN_MEMPHIS_RENDERER (champlain_map_source_get_renderer (CHAMPLAIN_MAP_SOURCE (tile_source)));
+  g_object_get (G_OBJECT (renderer), "bounding-box", &bbox, NULL);
   champlain_bounding_box_get_center (bbox, &lat, &lon);
 
-  champlain_view_center_on (CHAMPLAIN_VIEW(view), lat, lon);
-  champlain_view_set_zoom_level (CHAMPLAIN_VIEW(view), 15);
+  champlain_view_center_on (CHAMPLAIN_VIEW (view), lat, lon);
+  champlain_view_set_zoom_level (CHAMPLAIN_VIEW (view), 15);
 }
 
+
 static void
 request_osm_data_cb (GtkWidget *widget, ChamplainView *view)
 {
   gdouble lat, lon;
+
   g_object_get (G_OBJECT (view), "latitude", &lat, "longitude", &lon, NULL);
 
   if (g_strcmp0 (champlain_map_source_get_id (tile_source), "memphis-network") == 0)
     {
-      ChamplainNetworkMapDataSource *data_source =
-        CHAMPLAIN_NETWORK_MAP_DATA_SOURCE (
-          champlain_memphis_tile_source_get_map_data_source (
-            CHAMPLAIN_MEMPHIS_TILE_SOURCE(tile_source)));
-
-      champlain_network_map_data_source_load_map_data (data_source,
-          lon - 0.008, lat - 0.008, lon + 0.008, lat + 0.008);
+      ChamplainNetworkBboxTileSource *source = CHAMPLAIN_NETWORK_BBOX_TILE_SOURCE (tile_source);
+      load_network_map_data (source, view);
     }
 }
 
+
 void
 bg_color_set_cb (GtkColorButton *widget, ChamplainView *view)
 {
@@ -396,22 +408,26 @@ bg_color_set_cb (GtkColorButton *widget, ChamplainView *view)
 
   if (strncmp (champlain_map_source_get_id (tile_source), "memphis", 7) == 0)
     {
+      ChamplainMemphisRenderer *renderer;
       ClutterColor clutter_color;
       color_gdk_to_clutter (&gdk_color, &clutter_color);
 
-      champlain_memphis_tile_source_set_background_color (
-        CHAMPLAIN_MEMPHIS_TILE_SOURCE (tile_source), &clutter_color);
+      renderer = CHAMPLAIN_MEMPHIS_RENDERER (champlain_map_source_get_renderer (CHAMPLAIN_MAP_SOURCE (tile_source)));
+
+      champlain_memphis_renderer_set_background_color (renderer, &clutter_color);
+      reload_tiles ();
     }
 }
 
+
 static void
 map_source_changed (GtkWidget *widget, ChamplainView *view)
 {
-  gchar* id;
+  gchar *id;
   ChamplainMapSource *source;
-  ChamplainLocalMapDataSource *data;
   GtkTreeIter iter;
   GtkTreeModel *model;
+  ChamplainRenderer *renderer;
 
   if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter))
     return;
@@ -422,18 +438,19 @@ map_source_changed (GtkWidget *widget, ChamplainView *view)
 
   ChamplainMapSourceFactory *factory = champlain_map_source_factory_dup_default ();
   source = champlain_map_source_factory_create (factory, id);
+  renderer = champlain_map_source_get_renderer (CHAMPLAIN_MAP_SOURCE (source));
 
   if (source != NULL)
     {
       ChamplainMapSourceChain *source_chain;
       ChamplainMapSource *src;
+      ChamplainRenderer *image_renderer;
       guint tile_size;
 
       if (g_strcmp0 (id, "memphis-local") == 0)
         {
-          champlain_memphis_tile_source_load_rules (
-            CHAMPLAIN_MEMPHIS_TILE_SOURCE (source), rules[rules_index]);
-          load_local_map_data (source);
+          champlain_memphis_renderer_load_rules (CHAMPLAIN_MEMPHIS_RENDERER (renderer), rules[rules_index]);
+          champlain_file_tile_source_load_map_data (CHAMPLAIN_FILE_TILE_SOURCE (source), maps[map_index]);
           gtk_widget_hide_all (memphis_box);
           gtk_widget_set_no_show_all (memphis_box, FALSE);
           gtk_widget_set_no_show_all (memphis_local_box, FALSE);
@@ -442,9 +459,8 @@ map_source_changed (GtkWidget *widget, ChamplainView *view)
         }
       else if (g_strcmp0 (id, "memphis-network") == 0)
         {
-          champlain_memphis_tile_source_load_rules (
-            CHAMPLAIN_MEMPHIS_TILE_SOURCE (source), rules[rules_index]);
-          load_network_map_data (source, view);
+          champlain_memphis_renderer_load_rules (CHAMPLAIN_MEMPHIS_RENDERER (renderer), rules[rules_index]);
+          load_network_map_data (CHAMPLAIN_NETWORK_BBOX_TILE_SOURCE (source), view);
           gtk_widget_hide_all (memphis_box);
           gtk_widget_set_no_show_all (memphis_box, FALSE);
           gtk_widget_set_no_show_all (memphis_local_box, TRUE);
@@ -457,19 +473,20 @@ map_source_changed (GtkWidget *widget, ChamplainView *view)
           gtk_widget_set_no_show_all (memphis_box, TRUE);
         }
 
-      tile_source = CHAMPLAIN_MAP_SOURCE(source);
+      tile_source = CHAMPLAIN_MAP_SOURCE (source);
 
       source_chain = champlain_map_source_chain_new ();
 
       tile_size = champlain_map_source_get_tile_size (tile_source);
-      src = CHAMPLAIN_MAP_SOURCE(champlain_error_tile_source_new_full (tile_size));
+      src = champlain_map_source_factory_create_error_source (factory, tile_size);
 
       champlain_map_source_chain_push (source_chain, src);
       champlain_map_source_chain_push (source_chain, tile_source);
 
-      src = CHAMPLAIN_MAP_SOURCE(champlain_file_cache_new_full (100000000, NULL, FALSE));
-
-      champlain_map_source_chain_push (source_chain, src);
+      image_renderer = CHAMPLAIN_RENDERER (champlain_image_renderer_new ());
+      memory_cache = champlain_memory_cache_new_full (100, image_renderer);
+      
+      champlain_map_source_chain_push (source_chain, CHAMPLAIN_MAP_SOURCE (memory_cache));
 
       g_object_set (G_OBJECT (view), "map-source", source_chain, NULL);
       if (strncmp (id, "memphis", 7) == 0)
@@ -479,6 +496,7 @@ map_source_changed (GtkWidget *widget, ChamplainView *view)
   g_object_unref (factory);
 }
 
+
 static void
 map_data_changed (GtkWidget *widget, ChamplainView *view)
 {
@@ -495,13 +513,17 @@ map_data_changed (GtkWidget *widget, ChamplainView *view)
   map_index = index;
 
   if (g_strcmp0 (champlain_map_source_get_id (tile_source), "memphis-local") == 0)
-    load_local_map_data (tile_source);
+    {
+      champlain_file_tile_source_load_map_data (CHAMPLAIN_FILE_TILE_SOURCE (tile_source), maps[map_index]);
+      reload_tiles ();
+    }
 }
 
+
 static void
 rules_changed (GtkWidget *widget, ChamplainView *view)
 {
-  gchar* file;
+  gchar *file;
   GtkTreeIter iter;
   GtkTreeModel *model;
 
@@ -513,45 +535,54 @@ rules_changed (GtkWidget *widget, ChamplainView *view)
 
   if (strncmp (champlain_map_source_get_id (tile_source), "memphis", 7) == 0)
     {
-      champlain_memphis_tile_source_load_rules (
-        CHAMPLAIN_MEMPHIS_TILE_SOURCE (tile_source),
-        file);
+      ChamplainMemphisRenderer *renderer;
+
+      renderer = CHAMPLAIN_MEMPHIS_RENDERER (champlain_map_source_get_renderer (CHAMPLAIN_MAP_SOURCE (tile_source)));
+      champlain_memphis_renderer_load_rules (renderer, file);
       load_rules_into_gui (view);
+      reload_tiles ();
     }
 }
 
+
 static void
 zoom_changed (GtkSpinButton *spinbutton,
-              ChamplainView *view)
+    ChamplainView *view)
 {
   gint zoom = gtk_spin_button_get_value_as_int (spinbutton);
-  g_object_set (G_OBJECT(view), "zoom-level", zoom, NULL);
+
+  g_object_set (G_OBJECT (view), "zoom-level", zoom, NULL);
 }
 
+
 static void
 map_zoom_changed (ChamplainView *view,
-                  GParamSpec *gobject,
-                  GtkSpinButton *spinbutton)
+    GParamSpec *gobject,
+    GtkSpinButton *spinbutton)
 {
   gint zoom;
-  g_object_get (G_OBJECT(view), "zoom-level", &zoom, NULL);
+
+  g_object_get (G_OBJECT (view), "zoom-level", &zoom, NULL);
   gtk_spin_button_set_value (spinbutton, zoom);
 }
 
+
 static void
 zoom_in (GtkWidget *widget,
-         ChamplainView *view)
+    ChamplainView *view)
 {
   champlain_view_zoom_in (view);
 }
 
+
 static void
 zoom_out (GtkWidget *widget,
-          ChamplainView *view)
+    ChamplainView *view)
 {
   champlain_view_zoom_out (view);
 }
 
+
 static void
 build_source_combo_box (GtkComboBox *box)
 {
@@ -563,8 +594,8 @@ build_source_combo_box (GtkComboBox *box)
   GtkCellRenderer *cell;
 
   store = gtk_tree_store_new (N_COLS, G_TYPE_STRING, /* id */
-                              G_TYPE_STRING, /* name */
-                              -1);
+        G_TYPE_STRING,                       /* name */
+        -1);
 
   factory = champlain_map_source_factory_dup_default ();
   sources = champlain_map_source_factory_dup_list (factory);
@@ -574,11 +605,11 @@ build_source_combo_box (GtkComboBox *box)
     {
       ChamplainMapSourceDesc *desc;
 
-      desc = (ChamplainMapSourceDesc*) iter->data;
+      desc = (ChamplainMapSourceDesc *) iter->data;
 
       gtk_tree_store_append (store, &parent, NULL);
       gtk_tree_store_set (store, &parent, COL_ID, desc->id,
-                          COL_NAME, desc->name, -1);
+          COL_NAME, desc->name, -1);
 
       iter = g_slist_next (iter);
     }
@@ -591,9 +622,10 @@ build_source_combo_box (GtkComboBox *box)
   cell = gtk_cell_renderer_text_new ();
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (box), cell, FALSE);
   gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (box), cell,
-                                  "text", COL_NAME, NULL);
+      "text", COL_NAME, NULL);
 }
 
+
 static void
 build_data_combo_box (GtkComboBox *box)
 {
@@ -602,24 +634,25 @@ build_data_combo_box (GtkComboBox *box)
   GtkCellRenderer *cell;
 
   store = gtk_tree_store_new (2, G_TYPE_STRING, /* file name */
-                              G_TYPE_INT, /* index */ -1);
+        G_TYPE_INT, /* index */ -1);
 
   gtk_tree_store_append (store, &parent, NULL);
   gtk_tree_store_set (store, &parent, 0, maps[0],
-                      1, 0, -1);
+      1, 0, -1);
 
   gtk_tree_store_append (store, &parent, NULL);
   gtk_tree_store_set (store, &parent, 0, maps[1],
-                      1, 1, -1);
+      1, 1, -1);
 
   gtk_combo_box_set_model (box, GTK_TREE_MODEL (store));
 
   cell = gtk_cell_renderer_text_new ();
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (box), cell, FALSE);
   gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (box), cell,
-                                  "text", 0, NULL);
+      "text", 0, NULL);
 }
 
+
 static void
 build_rules_combo_box (GtkComboBox *box)
 {
@@ -639,50 +672,48 @@ build_rules_combo_box (GtkComboBox *box)
   cell = gtk_cell_renderer_text_new ();
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (box), cell, FALSE);
   gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (box), cell,
-                                  "text", 0, NULL);
+      "text", 0, NULL);
 }
 
-void list_item_selected_cb (GtkTreeView *tree_view,
-                            GtkTreePath *path,
-                            GtkTreeViewColumn *column,
-                            ChamplainView *view)
+
+void
+list_item_selected_cb (GtkTreeView *tree_view,
+    GtkTreePath *path,
+    GtkTreeViewColumn *column,
+    ChamplainView *view)
 {
   GtkTreeIter iter;
   GtkTreeModel *model;
   char *id;
   GtkTreeSelection *selection = gtk_tree_view_get_selection (tree_view);
-  MemphisRule *rule;
+  ChamplainMemphisRule *rule;
 
   if (rule_edit_window != NULL)
     return;
 
   if (gtk_tree_selection_get_selected (selection, &model, &iter))
     {
+      ChamplainMemphisRenderer *renderer;
+
+      renderer = CHAMPLAIN_MEMPHIS_RENDERER (champlain_map_source_get_renderer (CHAMPLAIN_MAP_SOURCE (tile_source)));
+
       gtk_tree_model_get (model, &iter, 0, &id, -1);
 
-      rule = champlain_memphis_tile_source_get_rule (CHAMPLAIN_MEMPHIS_TILE_SOURCE(tile_source), id);
+      rule = champlain_memphis_renderer_get_rule (renderer, id);
 
       if (rule != NULL)
-        create_rule_edit_window (rule, id, CHAMPLAIN_MEMPHIS_TILE_SOURCE(tile_source));
+        create_rule_edit_window (rule, id, renderer);
 
       g_free (id);
     }
 }
 
-static gboolean
-delete_window (GtkWidget *widget,
-               GdkEvent  *event,
-               gpointer   user_data)
-{
-  gtk_main_quit ();
-}
 
 int
 main (int argc,
-      char *argv[])
+    char *argv[])
 {
   GtkWidget *widget, *hbox, *bbox, *menubox, *button, *viewport, *label;
-  ChamplainView *view;
 
   g_thread_init (NULL);
   gtk_clutter_init (&argc, &argv);
@@ -701,7 +732,7 @@ main (int argc,
    * stop the main GTK loop
    */
   g_signal_connect (G_OBJECT (window), "destroy", G_CALLBACK (on_destroy),
-                    NULL);
+      NULL);
 
   hbox = gtk_hbox_new (FALSE, 10);
   menubox = gtk_vbox_new (FALSE, 10);
@@ -713,29 +744,29 @@ main (int argc,
   gtk_widget_set_no_show_all (memphis_local_box, TRUE);
 
   widget = gtk_champlain_embed_new ();
-  view = gtk_champlain_embed_get_view (GTK_CHAMPLAIN_EMBED (widget));
+  champlain_view = gtk_champlain_embed_get_view (GTK_CHAMPLAIN_EMBED (widget));
 
-  g_object_set (G_OBJECT (view), "scroll-mode", CHAMPLAIN_SCROLL_MODE_KINETIC,
-                "zoom-level", 9, NULL);
+  g_object_set (G_OBJECT (champlain_view), "scroll-mode", CHAMPLAIN_SCROLL_MODE_KINETIC,
+      "zoom-level", 9, NULL);
 
   gtk_widget_set_size_request (widget, 640, 480);
 
   /* first line of buttons */
-  bbox =  gtk_hbox_new (FALSE, 10);
+  bbox = gtk_hbox_new (FALSE, 10);
   button = gtk_button_new_from_stock (GTK_STOCK_ZOOM_IN);
-  g_signal_connect (button, "clicked", G_CALLBACK (zoom_in), view);
+  g_signal_connect (button, "clicked", G_CALLBACK (zoom_in), champlain_view);
   gtk_container_add (GTK_CONTAINER (bbox), button);
 
   button = gtk_button_new_from_stock (GTK_STOCK_ZOOM_OUT);
-  g_signal_connect (button, "clicked", G_CALLBACK (zoom_out), view);
+  g_signal_connect (button, "clicked", G_CALLBACK (zoom_out), champlain_view);
   gtk_container_add (GTK_CONTAINER (bbox), button);
 
   button = gtk_spin_button_new_with_range (0, 20, 1);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (button),
-                             champlain_view_get_zoom_level (view));
-  g_signal_connect (button, "changed", G_CALLBACK (zoom_changed), view);
-  g_signal_connect (view, "notify::zoom-level", G_CALLBACK (map_zoom_changed),
-                    button);
+      champlain_view_get_zoom_level (champlain_view));
+  g_signal_connect (button, "changed", G_CALLBACK (zoom_changed), champlain_view);
+  g_signal_connect (champlain_view, "notify::zoom-level", G_CALLBACK (map_zoom_changed),
+      button);
   gtk_container_add (GTK_CONTAINER (bbox), button);
 
   gtk_box_pack_start (GTK_BOX (menubox), bbox, FALSE, FALSE, 0);
@@ -744,7 +775,7 @@ main (int argc,
   button = gtk_combo_box_new ();
   build_source_combo_box (GTK_COMBO_BOX (button));
   gtk_combo_box_set_active (GTK_COMBO_BOX (button), 0);
-  g_signal_connect (button, "changed", G_CALLBACK (map_source_changed), view);
+  g_signal_connect (button, "changed", G_CALLBACK (map_source_changed), champlain_view);
   gtk_box_pack_start (GTK_BOX (menubox), button, FALSE, FALSE, 0);
 
   /* Memphis options */
@@ -756,18 +787,18 @@ main (int argc,
   button = gtk_combo_box_new ();
   build_data_combo_box (GTK_COMBO_BOX (button));
   gtk_combo_box_set_active (GTK_COMBO_BOX (button), 0);
-  g_signal_connect (button, "changed", G_CALLBACK (map_data_changed), view);
+  g_signal_connect (button, "changed", G_CALLBACK (map_data_changed), champlain_view);
   gtk_box_pack_start (GTK_BOX (memphis_local_box), button, FALSE, FALSE, 0);
 
   button = gtk_button_new_from_stock (GTK_STOCK_ZOOM_FIT);
-  g_signal_connect (button, "clicked", G_CALLBACK (zoom_to_map_data), view);
+  g_signal_connect (button, "clicked", G_CALLBACK (zoom_to_map_data), champlain_view);
   gtk_container_add (GTK_CONTAINER (memphis_local_box), button);
 
   gtk_box_pack_start (GTK_BOX (memphis_box), memphis_local_box, FALSE, FALSE, 0);
 
   /* network source panel */
   button = gtk_button_new_with_label ("Request OSM data");
-  g_signal_connect (button, "clicked", G_CALLBACK (request_osm_data_cb), view);
+  g_signal_connect (button, "clicked", G_CALLBACK (request_osm_data_cb), champlain_view);
   gtk_box_pack_start (GTK_BOX (memphis_net_box), button, FALSE, FALSE, 0);
 
   map_data_state_img = gtk_image_new ();
@@ -779,11 +810,11 @@ main (int argc,
   button = gtk_combo_box_new ();
   build_rules_combo_box (GTK_COMBO_BOX (button));
   gtk_combo_box_set_active (GTK_COMBO_BOX (button), 0);
-  g_signal_connect (button, "changed", G_CALLBACK (rules_changed), view);
+  g_signal_connect (button, "changed", G_CALLBACK (rules_changed), champlain_view);
   gtk_box_pack_start (GTK_BOX (memphis_box), button, FALSE, FALSE, 0);
 
   /* bg chooser */
-  bbox =  gtk_hbox_new (FALSE, 10);
+  bbox = gtk_hbox_new (FALSE, 10);
 
   label = gtk_label_new (NULL);
   gtk_label_set_markup (GTK_LABEL (label), "Background color");
@@ -791,14 +822,14 @@ main (int argc,
 
   bg_button = gtk_color_button_new ();
   gtk_color_button_set_title (GTK_COLOR_BUTTON (bg_button), "Background");
-  g_signal_connect (bg_button, "color-set", G_CALLBACK (bg_color_set_cb), view);
+  g_signal_connect (bg_button, "color-set", G_CALLBACK (bg_color_set_cb), champlain_view);
   gtk_box_pack_start (GTK_BOX (bbox), bg_button, FALSE, FALSE, 0);
 
   gtk_box_pack_start (GTK_BOX (memphis_box), bbox, FALSE, FALSE, 0);
 
   /* rules list */
   label = gtk_label_new ("Rules");
-  bbox =  gtk_hbox_new (FALSE, 10);
+  bbox = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (bbox), label, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (memphis_box), bbox, FALSE, FALSE, 0);
 
@@ -806,11 +837,10 @@ main (int argc,
   GtkWidget *tree_view, *scrolled;
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
-  GtkTreeSelection *selection;
 
   store = gtk_list_store_new (1, G_TYPE_STRING);
 
-  tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL(store));
+  tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   rules_tree_view = tree_view;
   g_object_unref (store);
   renderer = gtk_cell_renderer_text_new ();
@@ -819,13 +849,13 @@ main (int argc,
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column);
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree_view), FALSE);
 
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(tree_view));
-  g_signal_connect (tree_view, "row-activated", G_CALLBACK(list_item_selected_cb), view);
+  gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
+  g_signal_connect (tree_view, "row-activated", G_CALLBACK (list_item_selected_cb), champlain_view);
 
   scrolled = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW(scrolled), tree_view);
+      GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolled), tree_view);
 
   gtk_box_pack_start (GTK_BOX (memphis_box), scrolled, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (menubox), memphis_box, TRUE, TRUE, 0);
@@ -842,10 +872,9 @@ main (int argc,
 
   /* make sure that everything, window and label, are visible */
   gtk_widget_show_all (window);
-  champlain_view_center_on (CHAMPLAIN_VIEW(view), 28.13476, -15.43814);
+  champlain_view_center_on (CHAMPLAIN_VIEW (champlain_view), 28.13476, -15.43814);
   /* start the main loop */
   gtk_main ();
 
   return 0;
 }
-
